require 'spec_helper'

describe Stasis::Extensions::I18n do

  let(:project_folder) { File.expand_path('../../../../fixtures/project', __FILE__) }
  let(:stasis) { Stasis.new(project_folder) }

  describe "an instance of the plugin" do
    before do
      @plugin = Stasis::Extensions::I18n.new(stasis)
    end

    it "should set the I18n load_path" do
      expect(::I18n.load_path).to include(project_path('config/locales/en.yml'))
    end

    it "should set the default locale" do
      expect(::I18n.default_locale).to eq(:en)
    end

    it "should load the translations" do
      expect(::I18n.translate('i18n.t.hello')).to eq('Hello')
    end

    describe "#reset" do
      it "should set the I18n load_path" do
        ::I18n.load_path = []
        expect(::I18n.load_path).to_not include(project_path('config/locales/en.yml'))
        @plugin.reset
        expect(::I18n.load_path).to include(project_path('config/locales/en.yml'))
      end

      it "should set the default locale" do
        ::I18n.default_locale = :fr
        expect(::I18n.default_locale).to eq(:fr)
        @plugin.reset
        expect(::I18n.default_locale).to eq(:en)
      end

      it "should reload the translations" do
        expect(::I18n.translate('i18n.t.hello')).to eq('Hello')
        ::I18n.backend.store_translations('en', 'i18n' => {'t' => {'hello' => 'Hi'}})
        expect(::I18n.translate('i18n.t.hello')).to eq('Hi')
        @plugin.reset
        expect(::I18n.translate('i18n.t.hello')).to eq('Hello')
      end
    end

    describe "#before_all" do
      it "should use the default locale" do
        ::I18n.default_locale = :de
        @plugin.before_all
        expect(::I18n.locale).to eq(:de)
      end

      it "should use the locale in the LOCALE environment variable" do
        ENV.stub(:[]).with('LOCALE').and_return('es')
        @plugin.before_all
        expect(::I18n.locale).to eq(:es)
      end
    end
  end

  describe "when rendered" do
    describe "#body_class" do
      it "should render the locale and the view name" do
        stasis_render 'i18n/body_class.haml'
        expect(contents_of('public/i18n/body_class')).to eq([:en, "body_class"].inspect)
      end
    end

    describe "#root_url" do
      it "should render the url" do
        stasis_render 'i18n/root_url.haml'
        expect(contents_of('public/i18n/root_url')).to eq('http://example.com')
      end
    end

    describe "#t" do
      it "should render the value" do
        stasis_render 'i18n/t.haml'
        expect(contents_of('public/i18n/t')).to eq('Hello')
      end
    end
  end
end
